<?php
/**
 * Plugin Name: Floating Content
 * Plugin URI: https://example.com/floating-content
 * Description: A simple plugin to display floating content on your WordPress website
 * Version: 1.0.0
 * Author: Your Name
 * Author URI: https://example.com
 * Text Domain: floating-content
 */

// Exit if accessed directly
if (!defined('ABSPATH')) {
    exit;
}

// Register activation hook
register_activation_hook(__FILE__, 'floating_content_activate');

function floating_content_activate() {
    // Activation code here
}

// Register deactivation hook
register_deactivation_hook(__FILE__, 'floating_content_deactivate');

function floating_content_deactivate() {
    // Deactivation code here
}

// Enqueue scripts and styles
function floating_content_enqueue_scripts() {
    wp_enqueue_style('floating-content-style', plugin_dir_url(__FILE__) . 'assets/css/floating-content.css', array(), '1.0.0');
    wp_enqueue_script('floating-content-script', plugin_dir_url(__FILE__) . 'assets/js/floating-content.js', array('jquery'), '1.0.0', true);
}
add_action('wp_enqueue_scripts', 'floating_content_enqueue_scripts');

// Add admin menu
function floating_content_admin_menu() {
    add_menu_page(
        'Floating Content Settings',
        'Floating Content',
        'manage_options',
        'floating-content',
        'floating_content_settings_page',
        'dashicons-sticky',
        100
    );
}
add_action('admin_menu', 'floating_content_admin_menu');

// Settings page
function floating_content_settings_page() {
    // Check user capabilities
    if (!current_user_can('manage_options')) {
        return;
    }
    
    // Save settings
    if (isset($_POST['floating_content_submit'])) {
        // Verify nonce
        if (isset($_POST['floating_content_nonce']) && wp_verify_nonce($_POST['floating_content_nonce'], 'floating_content_save')) {
            // Save content
            update_option('floating_content_html', wp_kses_post($_POST['floating_content_html']));
            update_option('floating_content_position', sanitize_text_field($_POST['floating_content_position']));
            update_option('floating_content_enabled', isset($_POST['floating_content_enabled']) ? 1 : 0);
            
            // Show success message
            echo '<div class="notice notice-success is-dismissible"><p>Settings saved successfully!</p></div>';
        }
    }
    
    // Get saved options
    $content = get_option('floating_content_html', '');
    $position = get_option('floating_content_position', 'bottom-right');
    $enabled = get_option('floating_content_enabled', 0);
    
    // Display settings form
    ?>
    <div class="wrap">
        <h1><?php echo esc_html(get_admin_page_title()); ?></h1>
        <form method="post" action="">
            <?php wp_nonce_field('floating_content_save', 'floating_content_nonce'); ?>
            
            <table class="form-table">
                <tr>
                    <th scope="row">
                        <label for="floating_content_enabled">Enable Floating Content</label>
                    </th>
                    <td>
                        <input type="checkbox" id="floating_content_enabled" name="floating_content_enabled" value="1" <?php checked(1, $enabled); ?>>
                    </td>
                </tr>
                <tr>
                    <th scope="row">
                        <label for="floating_content_position">Position</label>
                    </th>
                    <td>
                        <select id="floating_content_position" name="floating_content_position">
                            <option value="top-left" <?php selected('top-left', $position); ?>>Top Left</option>
                            <option value="top-right" <?php selected('top-right', $position); ?>>Top Right</option>
                            <option value="bottom-left" <?php selected('bottom-left', $position); ?>>Bottom Left</option>
                            <option value="bottom-right" <?php selected('bottom-right', $position); ?>>Bottom Right</option>
                        </select>
                    </td>
                </tr>
                <tr>
                    <th scope="row">
                        <label for="floating_content_html">Content (HTML allowed)</label>
                    </th>
                    <td>
                        <?php
                        wp_editor($content, 'floating_content_html', array(
                            'textarea_name' => 'floating_content_html',
                            'textarea_rows' => 10,
                            'media_buttons' => true,
                        ));
                        ?>
                        <p class="description">Enter the content you want to display in the floating box.</p>
                    </td>
                </tr>
            </table>
            
            <p class="submit">
                <input type="submit" name="floating_content_submit" class="button-primary" value="Save Settings">
            </p>
        </form>
    </div>
    <?php
}

// Display floating content on the frontend
function floating_content_display() {
    // Check if enabled
    $enabled = get_option('floating_content_enabled', 0);
    if (!$enabled) {
        return;
    }
    
    // Get content and position
    $content = get_option('floating_content_html', '');
    $position = get_option('floating_content_position', 'bottom-right');
    
    // Output the floating content
    echo '<div id="floating-content" class="floating-content ' . esc_attr($position) . '">';
    echo '<div class="floating-content-inner">';
    echo '<span class="floating-content-close">&times;</span>';
    echo wp_kses_post($content);
    echo '</div>';
    echo '</div>';
}
add_action('wp_footer', 'floating_content_display');